/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.common.binaryfile;

import java.io.InputStream;
import java.util.function.BiFunction;
import java.util.function.Function;

import io.grpc.stub.CallStreamObserver;
import io.grpc.stub.StreamObserver;
import lombok.extern.log4j.Log4j2;

@Log4j2
class StreamExclusiveFileSender<Q, S> extends StreamingFileSender<Q, S> {

	private final Function<StreamObserver<S>, CallStreamObserver<Q>> reqObserverBuilder;
	private CallStreamObserver<Q> requestObserver;

	StreamExclusiveFileSender(BiFunction<byte[], Integer, Q> chunkBuilder, InputStream inputStream, Function<StreamObserver<S>, CallStreamObserver<Q>> reqObserverBuilder) {
		super(chunkBuilder, inputStream);

		this.reqObserverBuilder = reqObserverBuilder;
	}

	@Override
	public StreamExclusiveFileSender<Q, S> send() {
		LOG.debug("Start sending File.");

		var responseObserver = BinaryFileUploadStreamObserver.create(getResultFuture(), this::sendNext);
		requestObserver = reqObserverBuilder.apply(responseObserver);

		return this;
	}

	@Override
	void communicateEndOfTransfer() {
		requestObserver.onCompleted();
	}

	@Override
	protected CallStreamObserver<Q> getRequestObserver() {
		return requestObserver;
	}
}
